local helpIndex = 1

local basics = "Select a talent tier using the buttons on the left of the main window. You can then select a talent fromt hat tier using the buttons along the top.\n\nFrom there, you can review, edit and delete existing rules, aswell as adding new rules.\n\nRules are executed when you learn the chosen talent. The addon will search your macros for the text given in the left text box, and replace it with the text in the right text box. When you unlearn a talent, the process is reversed - searching your macros for the right text and replacing it with the left text.\n\n In this way, you can have TalentSwitch automatically modify, or outright change, your macros based on which talents you have selected.\n\n TalentSwitch will automatically change talent names in macros for you; but with Custom Rules, you can make more specific changes.\n\n For example, you may wish to add additional targeting parameters or add a non-GCD ability into a macro for a particular talent.\n\n You can also use this to replace passive talents in macros with other abilities.\n\n The following order applies for custom rules:\n1) Rules are reversed for inactive talents.\n2) Talent names are updated in macros to the active talent.\n3) Custom rules for teh active talent are applied.\n\n This means that it is always the talent with which the rule is associated that should be used when referencing talents in the relevent tier."
local list = "/tswitchlist [talentname [& talentname [& talentname [...]]]] \n\n List all the rules you have for a particular talent.\n\n The optional argument talentname allows you to specify a list of talents, seperated by the & sign, to view. With no argument, all talents stored are listed.\n"
local del = "/tswitchdel talentname & index \n\n Deletes a rule for the talent given by the talentname argument.\n\n Index is the number of the rule to be deleted, and can be found in square brackets using the /tswitchlist command\n"
local add = "/tswitchadd talentname & text_to_overwrite & text_to_add \n\n Adds a new rule to TalentSwitch.\n\n The rule will activate when you switch to the talent given by talentname.\n\n Any macros that contain text_to_overwrite will be changed to text_to_add.\n\n When you switch away from talent name, the rule will apply in reverse; removing text_to_add and putting text_to_overwrite in its place.\n\n Using \n will start a new line in your macro.\n You can make complex changes by using comments in macros to mark positions. Any line beginning with # is a comment (except #TSW# [which is used internally]).\n"
local examples = "Some examples: \n\nWhen I select 'Shadowstep'\n\nChange:\nShadowstep\n\nTo:\nShadowstep\n/use Redirect\n\nThis will add redirect to any macro with the Rogue tier 6 talents if Shadowstep is selected, but remove it otherwise. This wont work if you use Shadowstep in the middle of a line however.\n\n-------------------\n\n(using slash-commands)\n\n/tswitchadd Shadowstep & #t6marker & #t6marker\\n/use Redirect\n\nSimilar to above, this will add the use of Redirect to any macro marked by the position of the comment #t6marker in the macro text.\n\n This can be placed anywhere.\n\n-------------------\n\n/tswitchadd Celerity & /use Celerity & /use Touch of Death\n\nReplaces the Monk tier 2 talent Celerity with the skill Touch of Death when selected. This would be useful if you have a macro for a tier that has a mixture of active and passive options.\n\n When the passive (in this case Celerity) is selected, the macro is redirected to another useful active ability."
local slashCommands = "The following slash commands can be used instead of the graphical user-interface.\n\n'/tswitch' shows the main user-interface pane\n\n'/tswitchhelp' shows this window.\n'/tswitchhelp next' and '/tswitchhelp previous' allow you to scroll through the pages in this window.\n'/tswitch commands' shows a list of the major slash commands.\n\n\nContinue..."

tutorial = {	basics,
		slashCommands,
		list,
		add,
		del,
		examples
	}

function SlashCmdList.TSWITCHTUT(msg, editbox)
	if TSwitchTut == nil then
		TSwitchTut = CreateFrame("Frame", "", UIParent)
		TSwitchTut:SetPoint("LEFT", UIParent, "LEFT", 100, 100)
		TSwitchTut:SetWidth(600)
		TSwitchTut:SetHeight(600)
		TSwitchTut:SetFrameStrata("DIALOG")
		TSwitchTut:SetToplevel(true)
		TSwitchTut:SetMovable(true)
		TSwitchTut:SetScript("OnMouseDown", function() TSwitchTut:StartMoving() end)
		TSwitchTut:SetScript("OnMouseUp", function() TSwitchTut:StopMovingOrSizing() end)

		TSwitchTut.titleText = TSwitchTut:CreateFontString(nil, "BACKGROUND", "PVPInfoTextFont");
		TSwitchTut.titleText:SetPoint("TOP", TSwitchTut, "TOP", 0, -20)
		TSwitchTut.titleText:SetText("Help")

		TSwitchTut.text = TSwitchTut:CreateFontString(nil, "BACKGROUND", "GameFontNormal");
		TSwitchTut.text:SetPoint("TOPLEFT", TSwitchTut, "TOPLEFT", 20, -80)
		TSwitchTut.text:SetPoint("TOPRIGHT", TSwitchTut, "TOPRIGHT", -20, -80)
		TSwitchTut.text:SetPoint("BOTTOMLEFT", TSwitchTut, "BOTTOMLEFT", 20, -20)
		TSwitchTut.text:SetJustifyH("LEFT")
		TSwitchTut.text:SetJustifyV("TOP")
		TSwitchTut.text:SetText(tutorial[1])

		TSwitchTut.previous = CreateFrame("Button", "", TSwitchTut, "OptionsButtonTemplate")
		TSwitchTut.previous:SetPoint("BOTTOMLEFT", TSwitchTut, "TOPLEFT", 10, -40)
		TSwitchTut.previous:SetScript("OnClick", function() SlashCmdList.TSWITCHTUT("previous", nil) end)
		TSwitchTut.previous:SetText("<")
		TSwitchTut.previous:SetWidth(45)
		TSwitchTut.previous:Disable()

		TSwitchTut.next = CreateFrame("Button", "", TSwitchTut, "OptionsButtonTemplate")
		TSwitchTut.next:SetPoint("BOTTOMRIGHT", TSwitchTut, "TOPRIGHT", -10, -40)
		TSwitchTut.next:SetScript("OnClick", function() SlashCmdList.TSWITCHTUT("next", nil) end)
		TSwitchTut.next:SetText(">")
		TSwitchTut.next:SetWidth(45)
		TSwitchTut.next:Enable()

		TSwitchTut.close = CreateFrame("Button", "", TSwitchTut, "OptionsButtonTemplate")
		TSwitchTut.close:SetPoint("TOPRIGHT", TSwitchTut, "BOTTOMRIGHT", -10, 40)
		TSwitchTut.close:SetScript("OnClick", function() TSwitchTut:Hide() end)
		TSwitchTut.close:SetText("Close")
		TSwitchTut.close:SetWidth(45)
		TSwitchTut.close:Enable()

		TSwitchTut:SetBackdrop({
			bgFile = "Interface/Tooltips/UI-Tooltip-Background",
			edgeFile = "Interface/Tooltips/UI-Tooltip-Border",
			tile = true, tileSize = 32, edgeSize = 16,
			insets = { left = 5, right = 5, top = 5, bottom = 5 }
			})
		TSwitchTut:SetBackdropColor(0,0,0, 0.95)
	else

		if msg == "previous" then
			TSwitchTut:Show()
			if helpIndex ~= 1 then
				helpIndex = helpIndex - 1
			end
			if helpIndex == 1 then
				TSwitchTut.previous:Disable()
			end
			if helpIndex ~= #tutorial then
				TSwitchTut.next:Enable()
			end
			TSwitchTut.text:SetText(tutorial[helpIndex])
			return
		elseif msg == "next" then
			TSwitchTut:Show()
			if helpIndex ~= #tutorial then
				helpIndex = helpIndex + 1
			end
			if helpIndex == #tutorial then
				TSwitchTut.next:Disable()
			end
			if helpIndex ~= 1 then
				TSwitchTut.previous:Enable()
			end
			TSwitchTut.text:SetText(tutorial[helpIndex])
			return
		end

		if (TSwitchTut:IsVisible()) then
			TSwitchTut:Hide()
		else
			TSwitchTut:Show()
		end
	end
end